## Arches Controlled Lists 1.1.0 Release Notes

### Dependency changes:
```
Python:
    Upgraded:
        arches: >=8.1.0
    Added:
        None

    Removed:
        None


JavaScript:
    Upgraded:
        None

    Added:
        None

    Removed:
        None
```

### Major enhancements

- Adds a utility to modify the base url for controlled list items. [#210](https://github.com/archesproject/arches-controlled-lists/pull/210)
- Adds RDF methods (`to_rdf`, `from_rdf`, `get_rdf_uri`, `accepts_rdf_uri`, `ignore_keys`) to the reference datatype, enabling RDF serialization and deserialization of controlled list values. [#230](https://github.com/archesproject/arches-controlled-lists/pull/230)

### Additional highlights

- Fixed a bug where defaults values were not populated in the vue widget [#243](https://github.com/archesproject/arches-controlled-lists/issues/223)

### Upgrading Arches Controlled Lists

1. Upgrade python package
    ```
    pip install --upgrade arches-controlled-lists==1.1.0
    ```

1. Update webpack build
    ```
    npm run build_development
    python manage.py collectstatic
    ```

1. If you are running Arches on Apache, restart your server:
    ```
    sudo service apache2 reload
    ```
